from enum import Enum
from ..player import PlayerId
from ..animals import Animal
from .. import Money, Value
from dataclasses import dataclass
from typing import Union



class NoAction: ...
class Ok(NoAction): ...



class Draw:
    def __init__(self) -> None: ...

class Trade:
    data: InitialTrade
    def __init__(self, data: InitialTrade) -> None: ...

class InitialTrade:
    opponent: PlayerId
    animal: Animal
    animal_count: int
    amount: list[Money]

class PlayerTurnDecision:
    
    @staticmethod
    def Draw() -> PlayerTurnDecision: ...

    @staticmethod
    def Trade(initial_trade: InitialTrade) -> PlayerTurnDecision: ... 


class Buy:
    def __init__(self) -> None: ...

class Sell:
    def __init__(self) -> None: ...

class AuctionDecision:
    class Buy(AuctionDecision): ...
    class Sell(AuctionDecision): ...


class Accept:
    def __init__(self) -> None: ...

class CounterOffer:
    data: list[Money]
    def __init__(self, data: list[Money]) -> None: ...

class TradeOpponentDecision:
    class Accept(TradeOpponentDecision): ...
    class CounterOffer(TradeOpponentDecision):
        def __init__(self, data: list[Money]) -> None: ...


class WasBluff:
    def __init__(self) -> None: ...

class Amount:
    data: list[Money]
    def __init__(self, data: list[Money]) -> None: ...

SendMoney = Union[WasBluff, Amount]


class Pass:
    def __init__(self) -> None: ...

class Bid:
    data: Value
    def __init__(self, data: Value) -> None: ...

Bidding = Union[Pass, Bid]



from .player.player_actions import PlayerActions
class Client:
    def __init__(self, name: str, token: str, bot: PlayerActions, base_url: str): ...
    async def register(self): ...
    async def play_one_round(self, game_type_url: str): ...


from enum import Enum
from ..player import PlayerId
from ..animals import Animal
from .. import Money, Value
from .actions import Bidding


class AuctionRound:
    host: PlayerId
    animal: Animal
    bids: list[tuple[PlayerId, Bidding]]

class TradeOffer: 
    challenger: PlayerId
    animal: Animal
    animal_count: int
    challenger_card_offer: int

class GameUpdate: ...

class AuctionKind: ...
class MoneyTransfer: ...
class MoneyTrade: ...


class Wallet: 
    def __init__(self, bank_notes): ...

    def withdraw(self, amount): ...
    def deposit(self, amount): ...
    def total_money(self): ...
    def check_if_exact(self, bill_combination): ...
    def propose_bill_combinations(self, amount, also_suggest_smaller_values): ...
    def can_afford(self, payment_amount): ...
    def bank_notes(self): ...






from . import player_actions as player_actions
from . import simple_player as simple_player
from . import random_player as random_player
from . import wallet as wallet

from typing import TypeAlias
PlayerId: TypeAlias = str

__all__ = [
    "player_actions",
    "simple_player",
    "random_player",
    "wallet",
]
